@@ -1,6 +1,6 @@
 #' Compute FST from Pool-Seq data
 #' @param pooldata A pooldata object containing Pool-Seq information
-#' @param method Either "MoM" (default method as described in the manuscript) or "PiD" (relies on an alternative modeling consisting in estimating unbiased Probability of Identity within and across pairs of pools)
+#' @param method Either "Anova" (default method as described in the manuscript) or "Identity" (relies on an alternative modeling consisting in estimating unbiased Probability of Identity within and across pairs of pools)
 #' @param snp.index A list of SNP to be considered in the computation (by default all the SNP are considered)
 #' @return A list with the four following elements:
 #' \enumerate{
@@ -15,17 +15,17 @@
 #'  pooldata=popsync2pooldata(sync.file=paste0(tempdir(),"/ex.sync.gz"),poolsizes=rep(50,15))
 #'  res.fst=computeFST(pooldata)
 #' @export
-computeFST=function(pooldata,method="MoM",snp.index=NA){
-  if(!(method %in% c("PiD","MoM"))){stop("method should either be PID or MoM (default)")}
+computeFST=function(pooldata,method="Anova",snp.index=NA){
+  if(!(method %in% c("Identity","Anova"))){stop("method should either be Identity or Anova (default)")}
 	if(!(is.pooldata(pooldata))) {stop("The data are not formatted as a valid pooldata object...
-	  (see the readpooldata(), sync2pooldata or vcf2pooldata functions)")} 
+	  (see the popsync2pooldata, vcf2pooldata, genobaypass2pooldata and selestim2pooldata functions)")} 
   npop=pooldata@npools ; nsnp=pooldata@nsnp
   if(is.na(snp.index)){snp.index=1:nsnp}
   YY=pooldata@refallele.readcount[snp.index,]
   NN=pooldata@readcoverage[snp.index,]
   poolsize=pooldata@poolsizes
 
- if(method=="PiD"){
+ if(method=="Identity"){
   Q1=as.matrix((YY*(YY-1) + (NN-YY)*(NN-YY-1) )/(NN*(NN-1)))
   Q1 = (1/(matrix(1,nsnp,npop) %*% diag(poolsize-1)))*(Q1 %*% diag(poolsize) - 1)
   lambdaj=poolsize*(poolsize-1)
@@ -49,24 +49,24 @@ computeFST=function(pooldata,method="MoM",snp.index=NA){
   rslt=list(FST=(hat.Q1-hat.Q2)/(1-hat.Q2),snp.Q1=snp.Q1,snp.Q2=snp.Q2,snp.FST=(snp.Q1-snp.Q2)/(1-snp.Q2) )
  }
 
- if(method=="MoM"){
-  mtrx.n_i <- matrix(poolsize,nrow = nsnp,ncol = npop,byrow = TRUE)
-  R_1 = rowSums(NN) ; R_2 = rowSums(NN**2)
-  C_1 = rowSums(NN / mtrx.n_i + (mtrx.n_i - 1) / mtrx.n_i)
-  C_1.star <- rowSums(NN * (NN / mtrx.n_i + (mtrx.n_i - 1) / mtrx.n_i)) / R_1
-  n_c <- (R_1 - R_2 / R_1) / (C_1 - C_1.star)
-  YY2=NN-YY
-  SSI <- rowSums(YY - YY**2 / NN + YY2 - YY2**2 / NN)
-  SSP <- rowSums(NN * ((YY / NN) - (rowSums(YY) / R_1))^2 + NN * ((YY2 / NN) - (rowSums(YY2) / R_1))^2)
-  MSI <- SSI / (R_1 - C_1)
-  MSP <- SSP / (C_1 - C_1.star)
-  F_ST <- (MSP - MSI)  / (MSP + (n_c - 1) * MSI)
-  F_ST_multi <- sum( (MSP - MSI)[!is.na(F_ST)] )  / sum( (MSP + (n_c - 1) * MSI)[!is.na(F_ST)] )
-  Q_1 <- 1 - MSI
-  Q_2 <- 1 - MSI - (MSP - MSI) / n_c
-  rslt <- list(snp.FST = F_ST,snp.Q1 = Q_1,snp.Q2 = Q_2,FST = F_ST_multi)
- }
-
-  return(rslt) 
-  
-  }
+	if (method=="Anova"){
+		mtrx.n_i <- matrix(poolsize,nrow = nsnp,ncol = npop,byrow = TRUE)
+		C_1 <- rowSums(NN)
+		C_2 <- rowSums(NN^2)
+		D_2 <- rowSums(NN / mtrx.n_i + (mtrx.n_i - 1) / mtrx.n_i,na.rm = TRUE)
+		D_2.star <- rowSums(NN * (NN / mtrx.n_i + (mtrx.n_i - 1) / mtrx.n_i),na.rm = TRUE) / C_1
+		n_c <- (C_1 - C_2 / C_1) / (D_2 - D_2.star)
+		YY_alt <- NN - YY
+		SSI <- rowSums(YY - YY^2 / NN + YY_alt - YY_alt^2 / NN,na.rm = TRUE)
+		SSP <- rowSums(NN * ((YY / NN) - (rowSums(YY) / C_1))^2 + NN * ((YY_alt / NN) - (rowSums(YY_alt) / C_1))^2,na.rm = TRUE)
+		MSI <- SSI / (C_1 - D_2)
+		MSP <- SSP / (D_2 - D_2.star)
+		F_ST <- (MSP - MSI)  / (MSP + (n_c - 1) * MSI)
+		keep <- !is.na(F_ST)
+		F_ST_multi <- sum(MSP[keep] - MSI[keep])  / sum(MSP[keep] + (n_c[keep] - 1) * MSI[keep])
+		Q_1 <- 1 - MSI
+		Q_2 <- 1 - MSI - (MSP - MSI) / n_c
+		rslt <- list(snp.FST = F_ST,snp.Q1 = Q_1,snp.Q2 = Q_2,FST = F_ST_multi)
+	}
+	return(rslt)
+}
